@@ -91,7 +91,15 @@ def decodeCustomTx(hex,DfMarker):
         elif functionMarker == 'S':
             res = decodeDepositToVault(hex[2:])
             if res != None:
-                res['name'] = 'deposittovault'          
+                res['name'] = 'deposittovault'
+        elif functionMarker == 'U':
+            res = decodeUTXOsToAccount(hex[2:])
+            if res != None:
+                res['name'] = 'utxostoaccount'          
+        elif functionMarker == 'b':
+            res = decodeAccountToUTXOs(hex[2:])
+            if res != None:
+                res['name'] = 'accounttoutxos'                    
         else:
             c = CustomTxType()
             for key, value in asdict(c).items():
@@ -395,7 +403,30 @@ def decodeDepositToVault(hex):
         {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
     ]
     return searchHex(variables,hex)
+def decodeUTXOsToAccount(hex):
+    variables = [
+        {'key': 'tx', 'type': [
+            {'key': 'from', 'type': 'address','endian':None},
+            {'key': 'amounts', 'type': [
+                {'bytesCount': 4,'key': 'placeholder', 'type': int,'endian':'little'},
+                {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
+            ]}
+        ]}
+    ]
+    return searchHex(variables,hex)
+def decodeAccountToUTXOs(hex):
+    variables = [
+        {'key': 'from', 'type': 'address','endian':None},
+        {'key': 'amounts', 'type': [
+            {'bytesCount': 4,'key': 'placeholder', 'type': int,'endian':'little'},
+            {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'},
+            {'bytesCount': 1, 'key': 'mintingOutputStart', 'type': int,'endian':'little'}
+        ]}
+    ]
+    return searchHex(variables,hex)
 
+
+ 
 # NOT a DfTx Function!
 def decodeDfTxTokenSplit(hex):
     variables = [
